moviepy.video.fx.all.margin — MoviePy 1.0.1 documentation

# moviepy.video.fx.all.margin

`moviepy.video.fx.all.` `margin`(clip, mar=None, left=0, right=0, top=0, bottom=0, color=(0, 0, 0), opacity=1.0)

  Draws an external margin all around the frame.

  Parameters

    - mar – if not `None`, then the new clip has a margin of size `mar` in pixels on the left, right, top, and bottom.

    - right, top, bottom (left,) – width of the margin in pixel in these directions.

    - color – color of the margin.

    - mask_margin – value of the mask on the margin. Setting this value to 0 yields transparent margins.